/*******************************************************************************
 * University of Illinois/NCSA
 * Open Source License
 *
 * Copyright (c) 2011, NCSA.  All rights reserved.
 *
 * Developed by:
 * Cyberenvironments and Technologies (CET)
 * http://cet.ncsa.illinois.edu/
 *
 * National Center for Supercomputing Applications (NCSA)
 * http://www.ncsa.illinois.edu/
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the 
 * "Software"), to deal with the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimers.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimers in the
 *   documentation and/or other materials provided with the distribution.
 * - Neither the names of CET, University of Illinois/NCSA, nor the names
 *   of its contributors may be used to endorse or promote products
 *   derived from this Software without specific prior written permission.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE CONTRIBUTORS OR COPYRIGHT HOLDERS BE LIABLE FOR
 * ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
 * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS WITH THE SOFTWARE.
 *******************************************************************************/
package edu.illinois.ncsa.paw.domain;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.OneToOne;

import edu.illinois.ncsa.domain.AbstractBean;

/**
 * EAIRS metadata attributes for published workflow (simulation).
 * 
 * @author Luigi Marini
 * 
 */
@Entity(name = "EAIRSMetadata")
@SuppressWarnings("serial")
public class EAIRSMetadata extends AbstractBean {

    @OneToOne(fetch = FetchType.EAGER, cascade = { CascadeType.MERGE })
    private EAIRSMetadataModel          model;

    @OneToOne(fetch = FetchType.EAGER, cascade = { CascadeType.MERGE })
    private EAIRSMetadataPreprocessor   preprocessor;

    @OneToOne(fetch = FetchType.EAGER, cascade = { CascadeType.MERGE })
    private EAIRSMetadataSimulationTool simulationTool;

    @OneToOne(fetch = FetchType.EAGER, cascade = { CascadeType.MERGE })
    private EAIRSMetadataPostprocessor  postprocessor;

    private String                      publishedWorkflowId;

    public EAIRSMetadata() {}

    public EAIRSMetadataModel getModelType() {
        return model;
    }

    public void setModelType(EAIRSMetadataModel modelType) {
        this.model = modelType;
    }

    public EAIRSMetadataPreprocessor getPreprocessor() {
        return preprocessor;
    }

    public void setPreprocessor(EAIRSMetadataPreprocessor preprocessor) {
        this.preprocessor = preprocessor;
    }

    public EAIRSMetadataSimulationTool getSimulationTool() {
        return simulationTool;
    }

    public void setSimulationTool(EAIRSMetadataSimulationTool simulationTool) {
        this.simulationTool = simulationTool;
    }

    public EAIRSMetadataPostprocessor getPostprocessor() {
        return postprocessor;
    }

    public void setPostprocessor(EAIRSMetadataPostprocessor postprocessor) {
        this.postprocessor = postprocessor;
    }

    public String getPublishedWorkflowId() {
        return publishedWorkflowId;
    }

    public void setPublishedWorkflowId(String publishedWorkflowId) {
        this.publishedWorkflowId = publishedWorkflowId;
    }

}
