/*******************************************************************************
 * Copyright (c) 2012 University of Illinois/NCSA.  All rights reserved.
 * 
 *   National Center for Supercomputing Applications (NCSA)
 *   http://www.ncsa.illinois.edu/
 * 
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the 
 * "Software"), to deal with the Software without restriction, including 
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 * 
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimers.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimers in the
 *   documentation and/or other materials provided with the distribution.
 * - Neither the names of University of Illinois, NCSA, nor the names
 *   of its contributors may be used to endorse or promote products
 *   derived from this Software without specific prior written permission.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE CONTRIBUTORS OR COPYRIGHT HOLDERS BE LIABLE FOR
 * ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
 * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS WITH THE SOFTWARE.
 ******************************************************************************/
package edu.illinois.ncsa.paw.domain;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import javax.persistence.CascadeType;
import javax.persistence.CollectionTable;
import javax.persistence.Column;
import javax.persistence.ElementCollection;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.FetchType;
import javax.persistence.JoinTable;
import javax.persistence.OneToMany;

import edu.illinois.ncsa.datawolf.domain.Workflow;
import edu.illinois.ncsa.domain.AbstractBean;

/**
 * Configuration of input widget to show on web UI for a specific
 * {@link Workflow}.
 * 
 * @author Luigi Marini
 * 
 */
@Entity(name = "InputConfiguration")
public class InputConfiguration extends AbstractBean {

    /** Pretty name */
    private String  title;

    /** Long description */
    private String  description;

    /**
     * Id of widget to instantiate in web UI.
     * In GWT this is the name of the class implementing the widget.
     */
    private String  widgetId;

    /**
     * Whether to hide this input or not. Used for situations where defaults
     * need to be set but not changed.
     */
    private boolean hidden;

    /** Input types */
    public enum TYPE {
        INT, FLOAT, ENUMERATION, STRING, DATASET, NOTYPE
    }

    /** Input type **/
    @Enumerated(EnumType.STRING)
    private TYPE                  type             = TYPE.NOTYPE;

    /** Min allowed for numbers **/
    private String                minValue;

    /** Max allowed for numbers **/
    private String                maxValue;

    /** Default value **/
    private String                defaultValue;

    /** Map of value to string to show in widget **/
    @ElementCollection
    @Column(name = "value")
    @CollectionTable(name = "InputConfigurationEnumeration")
    private Map<String, String>   enumeration;

    /** List of marked paratemers. */
    @OneToMany(fetch = FetchType.LAZY, cascade = { CascadeType.MERGE })
    @JoinTable(name = "InputConfigurationMarkedParameters")
    private List<MarkedParameter> markedParameters = new ArrayList<MarkedParameter>();

    /** Used for serialization of object */
    private static final long     serialVersionUID = 1L;

    /**
     * Default constructor.
     */
    public InputConfiguration() {}

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getWidgetId() {
        return widgetId;
    }

    public void setWidgetId(String widgetId) {
        this.widgetId = widgetId;
    }

    public String getType() {
        if (type == null) {
            return TYPE.NOTYPE.toString();
        } else {
            return type.toString();
        }
    }

    public void setType(String type) {
        this.type = TYPE.valueOf(type);
    }

    public String getMinValue() {
        return minValue;
    }

    public void setMinValue(String min) {
        this.minValue = min;
    }

    public String getMaxValue() {
        return maxValue;
    }

    public void setMaxValue(String max) {
        this.maxValue = max;
    }

    public String getDefaultValue() {
        return defaultValue;
    }

    public void setDefaultValue(String defaultValue) {
        this.defaultValue = defaultValue;
    }

    public boolean isHidden() {
        return hidden;
    }

    public void setHidden(boolean hidden) {
        this.hidden = hidden;
    }

    public List<MarkedParameter> getMarkedParameters() {
        return markedParameters;
    }

    public void setMarkedParameters(List<MarkedParameter> markedParameters) {
        this.markedParameters = markedParameters;
    }

    public void addMarkedParameter(MarkedParameter markedParameter) {
        this.markedParameters.add(markedParameter);
    }

    public Map<String, String> getEnumeration() {
        return enumeration;
    }

    public void setEnumeration(Map<String, String> enumeration) {
        this.enumeration = enumeration;
    }

}
